@@ -1,4 +1,5 @@
 import asyncio
+import os
 import sys
 import typing
 from concurrent.futures import ThreadPoolExecutor
@@ -77,14 +78,29 @@ class Body:
             yield self.readline()
 
 
+ENC, ESC = sys.getfilesystemencoding(), "surrogateescape"
+
+
+def unicode_to_wsgi(u):
+    """Convert an environment variable to a WSGI "bytes-as-unicode" string"""
+    return u.encode(ENC, ESC).decode("iso-8859-1")
+
+
 def build_environ(scope: Scope, body: Body) -> Environ:
     """
     Builds a scope and request body into a WSGI environ object.
     """
+    allow_rewrite_environ = {
+        "SCRIPT_NAME": scope.get("root_path", "").encode("utf8").decode("latin1"),
+    }
+    for key in allow_rewrite_environ.keys():
+        environ_var = os.environ.get(key, "")
+        if environ_var:
+            allow_rewrite_environ[key] = unicode_to_wsgi(environ_var)
     environ = {
+        **allow_rewrite_environ,
         "asgi.scope": scope,
         "REQUEST_METHOD": scope["method"],
-        "SCRIPT_NAME": scope.get("root_path", "").encode("utf8").decode("latin1"),
         "PATH_INFO": scope["path"].encode("utf8").decode("latin1"),
         "QUERY_STRING": scope["query_string"].decode("ascii"),
         "SERVER_PROTOCOL": f"HTTP/{scope['http_version']}",
